- net_NOP
- net_Disconnect
- net_File
- net_SplitScreenUser
- net_Tick
- net_StringCmd
- net_SetConVar
- net_SignonState
- net_PlayerAvatarData
- svc_ServerInfo
- svc_SendTable
- svc_ClassInfo
- svc_SetPause
- svc_CreateStringTable
- svc_UpdateStringTable
- svc_VoiceInit
- svc_VoiceData
- svc_Print
- svc_Sounds
- svc_SetView
- svc_FixAngle
- svc_CrosshairAngle
- svc_BSPDecal
- svc_SplitScreen
- svc_UserMessage
- svc_EntityMessage
- svc_GameEvent
- svc_PacketEntities
- svc_TempEntities
- svc_Prefetch
- svc_Menu
- svc_GameEventList
- svc_GetCvarValue
- svc_PaintmapData
- svc_CmdKeyValues
- svc_EncryptedData
- svc_HltvReplay
- svc_Broadcast_Command
